==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebColumnToggledEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnToggledEventArgsDetailDescription } from "./WebColumnToggledEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebColumnToggledEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnToggledEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnToggledEventArgsDetailDescriptionMetadata.a == null) {
                WebColumnToggledEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnToggledEventArgsDetailDescriptionMetadata.c(WebColumnToggledEventArgsDetailDescriptionMetadata.a);
            }
            if (a.j(WebColumnToggledEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.y(WebColumnToggledEventArgsDetailDescriptionMetadata.a);
            WebColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ColumnToggledEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Column", "ExportedType:WebColumn");
            a.item("Checked", "Boolean");
        }
        static d(a) {
            WebColumnToggledEventArgsDetailDescriptionMetadata.b(a);
            a.aa("WebColumnToggledEventArgsDetail", () => new WebColumnToggledEventArgsDetailDescription());
            a.z("WebColumnToggledEventArgsDetail", WebColumnToggledEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebColumnToggledEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnToggledEventArgsDetailDescriptionMetadata, 'WebColumnToggledEventArgsDetailDescriptionMetadata');
    WebColumnToggledEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnToggledEventArgsDetailDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebColumnToggledEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebColumnDescriptionMetadata } from "./WebColumnDescriptionMetadata";
import { WebBaseEventArgsDetailDescriptionMetadata } from "./WebBaseEventArgsDetailDescriptionMetadata";
import { WebColumnToggledEventArgsDetailDescription } from "./WebColumnToggledEventArgsDetailDescription";
/**
 * @hidden
 */
export let WebColumnToggledEventArgsDetailDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebColumnToggledEventArgsDetailDescriptionMetadata extends Base {
        static b(a) {
            if (WebColumnToggledEventArgsDetailDescriptionMetadata.a == null) {
                WebColumnToggledEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebColumnToggledEventArgsDetailDescriptionMetadata.c(WebColumnToggledEventArgsDetailDescriptionMetadata.a);
            }
            if (a.k(WebColumnToggledEventArgsDetailDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebColumnToggledEventArgsDetailDescriptionMetadata.a);
            WebColumnDescriptionMetadata.d(a);
        }
        static c(a) {
            WebBaseEventArgsDetailDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:ColumnToggledEventArgsDetail");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            a.item("__skipSuffix", "Boolean");
            a.item("Column", "ExportedType:WebColumn");
            a.item("Checked", "Boolean");
        }
        static d(a) {
            WebColumnToggledEventArgsDetailDescriptionMetadata.b(a);
            a.ac("WebColumnToggledEventArgsDetail", () => new WebColumnToggledEventArgsDetailDescription());
            a.ab("WebColumnToggledEventArgsDetail", WebColumnToggledEventArgsDetailDescriptionMetadata.a);
        }
    }
    WebColumnToggledEventArgsDetailDescriptionMetadata.$t = /*@__PURE__*/ markType(WebColumnToggledEventArgsDetailDescriptionMetadata, 'WebColumnToggledEventArgsDetailDescriptionMetadata');
    WebColumnToggledEventArgsDetailDescriptionMetadata.a = null;
    return WebColumnToggledEventArgsDetailDescriptionMetadata;
})();
